word — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- export »

# word

`camelot.view.export.word.` `open_document_in_word`(filename)

  Try to open a document using word and return the word application com object if succeeded :return: (word, doc) a tuple of the com objects pointing to the word application, and the opened document. returns (None, None) if unable to open document using word

`camelot.view.export.word.` `open_html_in_word`(html, template='/home/tw55413/workspaces/camelot/svn/trunk/camelot/art/empty_document.doc', pre_processor=<function <lambda> at 0xca40ed4>, post_processor=<function <lambda> at 0xca40e64>)

  Open MS Word through COM objects and import the specified html into a new document. @param html: the html to import @param template: the empty word document in which to import the html @param post_processor: a function that will be called before importing the html, with as its argument the COM Document. @param post_processor: a function that will be called after importing the html, with as its argument the COM Document.

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- export »

Comments
blog comments powered by Disqus